/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-status-dialog-controller
 */

(function() {
var AutoDownloadStatusDialogController;
var prototype;
var superConstructor;
var AutoDownloadStatusDialogView = dixim.autoDownload.AutoDownloadStatusDialogView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientAutoDownload = dixim.common.ApiClientAutoDownload;

/**
 * @class AutoDownloadStatusDialogController
 * @constructor
 * @param {Object} configs
 */
AutoDownloadStatusDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AutoDownloadStatusDialogController, EventTarget);
dixim.autoDownload.AutoDownloadStatusDialogController = AutoDownloadStatusDialogController;
prototype = AutoDownloadStatusDialogController.prototype;
superConstructor = AutoDownloadStatusDialogController.superConstructor;

var UPDATE = 'update';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._model = new ApiClientAutoDownload();
    this._model.addEventListener('fetchItemList', this._successFetchItemList, this);
    this._model.addEventListener('fetchItemListError', this._errorFetchItemList, this);

    this._view = new AutoDownloadStatusDialogView(configs);
    this._view.addEventListener(UPDATE, this._clickUpdate, this);

    this._taskInfo = configs.taskInfo;
};

/**
 * @method start
 */
prototype.start = function() {
    var query = {};

    this._view.show();

    query.taskIds = [this._taskInfo.taskId];
    this._model.fetchItemList(query);
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._successFetchItemList = function(e) {
    var items = e.args.items;
    var itemsLen;

    for (var i = 0; i < items.length; i += 1) {
        switch(items[i].state) {
        case 4:
        case 8:
            items.splice(i, 1);
            i -= 1;
            break;
        }
    }
    itemsLen = items.length;

    if (itemsLen === 0) {
        this._view.noRow();
        return;
    }
    if (itemsLen > 10000) itemsLen = 10000;

    for (var i = 0; i < itemsLen; i += 1) {
        this._view.addRow(items[i]);
    }
};

prototype._errorFetchItemList = function() {
    this._view.error(_('auto_download_status_fetch_error'));
};

prototype._clickUpdate = function() {
    this._update();
};

prototype._update = function() {
    var query = {};

    this._view.cleanList();

    query.taskIds = [this._taskInfo.taskId];
    this._model.fetchItemList(query);
};

}());
