/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule parental-edit-setting-view
 */

(function() {
var ParentalEditSettingView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class ParentalEditSettingView
 * @constructor
 * @param {Object} configs
 */
ParentalEditSettingView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ParentalEditSettingView, EventTarget);
dixim.server.ParentalEditSettingView = ParentalEditSettingView;
prototype = ParentalEditSettingView.prototype;
superConstructor = ParentalEditSettingView.superConstructor;

var APPLY = 'apply';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = _('server_parental_menu_edit_setting_title');
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<div class="dl_tbl">',
        '<dl>',
        '<dt>', _('server_parental_edit_setting_current_name'), '</dt>',
        '<dd>',
        '<div id="parental_edit_setting_current" type="text" class="server_parental_limit" readonly="readonly">', '</div>',
        '</dd>',
        '</dl>',
        '<dl>',
        '<dt>', _('server_parental_edit_setting_new_name'), '</dt>',
        '<dd>',
        '<p>', _('server_parental_edit_setting_new_detail'), '</p>',
        '<select id="parental_level_select" class="select-pointer">', '</select>',
        '</dd>',
        '</dl>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    this._setSelectOptions();
 
    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    UiUtils.setActionBar('ab_apply', dixim.proxy(this._clickApply, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype._setSelectOptions = function() {
    var parentalLevelTextIdList = [
        'server_parental_edit_setting_new_limited_val',
        'server_parental_edit_setting_new_val',
        'server_parental_edit_setting_new_unlimited_val',
    ];
    var parentalLevelTextIdListLen = parentalLevelTextIdList.length;
    var parentalMexAge = 20;
    var idx = 0;

    $('#parental_level_select').empty();
    for (var i = 0; i <= parentalMexAge - 3; i += 1) {
        if (i !== 0) idx = 1;
        if ((i + 3) === parentalMexAge) idx = 2;

        $('#parental_level_select').append([
            '<option value="', i, '">', _(parentalLevelTextIdList[idx], (i + 3)), '</option>',
        ].join(''));
    }
};

prototype.setValue = function(ageLimit) {
    var parentalLevelTextIdList = [
        'server_parental_edit_setting_current_limited_val',
        'server_parental_edit_setting_current_val',
        'server_parental_edit_setting_current_unlimited_val',
    ];
    var parentalLevelTextIdListLen = parentalLevelTextIdList.length;
    var parentalMexAge = 20;
    var idx = 0;

    if (ageLimit !== 0) idx = 1;
    if (ageLimit === parentalMexAge) idx = 2; 

    $('#parental_edit_setting_current').html(_(parentalLevelTextIdList[idx], ageLimit));

    if (ageLimit !== 0) ageLimit -= 3;
    $('#parental_level_select').val(ageLimit);
};

prototype.setErrorValue = function() {
    $('#parental_edit_setting_current').html(_('server_parental_edit_setting_current_error_val'))
};

prototype._clickApply = function() {
    var ageLimit = parseInt($('#parental_level_select').val(), 10);

    this.dispatchEvent(new Event(APPLY, {ageLimit: ageLimit}));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

}());
