/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule progress-dialog-controller
 */

(function() {
var ProgressDialogController;
var prototype;
var superConstructor;
var ProgressDialogView = dixim.server.ProgressDialogView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var Enum = dixim.ctt.util.Enum;

/**
 * @class ProgressDialogController
 * @constructor
 * @param {Object} configs
 */
ProgressDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ProgressDialogController, EventTarget);
dixim.server.ProgressDialogController = ProgressDialogController;
prototype = ProgressDialogController.prototype;
superConstructor = ProgressDialogController.superConstructor;

var YES = 'yes';
var COMPLETE = 'complete';
var CLOSE = 'close';
var UPDATE = 'update';

var Mode = Enum.fetch('PROGRESS');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'progress-dialog'].join('');

    this._mode = configs.mode;

    switch(this._mode) {
        case Mode.SYNC_PUBLIC:
            this._model = new dixim.common.ApiClientServer();
            this._model.addEventListener('syncSharedFolder', this._success, this);
            this._model.addEventListener('syncSharedFolderError', this._error, this);
            break;
    }

    this._view = new ProgressDialogView(configs);
    this._view.addEventListener(YES, this._clickYes, this);
    this._view.addEventListener(COMPLETE, this.complete, this);

    this._contents = configs.contents;
    this._isProcessError;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._success = function() {
    this._view.decrementDescription();
};

prototype._error = function() {
    this._isProcessError = true;
    this._view.decrementDescription();
};

prototype._executeContents = function() {
    var contentsLen = this._contents.length;
    var query = {};

    this._isProcessError = false;
    for (var i = 0; i < contentsLen; i += 1) {
        switch(this._mode) {
            case Mode.SYNC_PUBLIC:
                query.sharedFolder = this._contents[i].path;
                this._model.syncSharedFolder(query);
                break;
        }
    }
};

prototype.complete = function() {
    this.stop();
    if (this._isProcessError) {
        switch(this._mode) {
            case Mode.SYNC_PUBLIC:
                this._errorDialog(_('server_public_folder_sync_error'));
                break;
        }
        this.dispatchEvent(new Event(CLOSE));
    } else {
        this.dispatchEvent(new Event(UPDATE));
    }
};

prototype._clickYes = function() {
    this._executeContents();
};

prototype._errorDialog = function(text) {
    var query = {};
    var dialog;

    switch(this._mode) {
        case Mode.SYNC_PUBLIC:
            query.title = _('server_public_folder_sync_title');
            break;
    }

    query.id = this._id;
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
