/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule aggregation-operation-controller
 */

(function() {
var AggregationOperationController;
var prototype;
var superConstructor;
var AggregationOperationView = dixim.vdms.AggregationOperationView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var AggregationOperationController = dixim.vdms.AggregationOperationController;
var AggregationOperationMenuDialogController = dixim.vdms.AggregationOperationMenuDialogController;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var ApiClientVdms = dixim.common.ApiClientVdms;
var BlockUi = dixim.common.BlockUi;

/**
 * @class AggregationOperationController
 * @constructor
 * @param {Object} configs
 */
AggregationOperationController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AggregationOperationController, EventTarget);
dixim.vdms.AggregationOperationController = AggregationOperationController;
prototype = AggregationOperationController.prototype;
superConstructor = AggregationOperationController.superConstructor;

var PREV = 'prev';
var REFRESH = 'refresh';
var SELECT = 'select';
var OPERATE = 'operate';
var UPDATE = 'update';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'aggregation-operation'].join('');

    this._model = new ApiClientVdms();
    this._model.addEventListener('fetchAggregationList', this._successFetchList, this);
    this._model.addEventListener('fetchAggregationListError', this._errorFetchList, this);
    this._model.addEventListener('fetchNonAggregationList', this._successFetchList, this);
    this._model.addEventListener('fetchNonAggregationListError', this._errorFetchList, this);

    this._view = new AggregationOperationView(configs);
    this._view.addEventListener(PREV, this._clickPrev, this);
    this._view.addEventListener(REFRESH, this._clickRefresh, this);
    this._view.addEventListener(OPERATE, this._clickOperate, this);
    this._view.addEventListener(SELECT, this._clickSelect, this);

    this._isAggregatedDevice = configs.isAggregatedDevice;
    this._parentContext = configs.parentContext;
    this._blockUi = new BlockUi();
    if (this._isAggregatedDevice) {
        this.title = _('vdms_aggregation_menu_aggregation');
    } else {
        this.title = _('vdms_aggregation_menu_non_aggregation');
    }
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
    this._fetchList();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._fetchList = function() {
    this._blockUi.block();
    if (this._isAggregatedDevice) {
        this._model.fetchAggregationList();
    } else {
        this._model.fetchNonAggregationList();
    }
};

prototype._successFetchList = function(e) {
    var dmsList = e.args.DMSList;

    this._viewList(dmsList);
    this._blockUi.unblock();
};

prototype._errorFetchList = function(e) {
    this._view.error((this._isAggregatedDevice) ? _('vdms_aggregation_error_fetch_aggregation') : _('vdms_aggregation_error_fetch_non_aggregation'));
    this._blockUi.unblock();
};

prototype._viewList = function(list) {
    var listLen = list.length;

    if (listLen === 0) {
        this._view.noDevice();
        return;
    }
    for (var i = 0; i < listLen; i += 1) {
        this._view.addDevice(list[i]);
    }
};

prototype._errorDialog = function(text) {
    var dialog = null;
    var query = {};

    query.id = this._id;
    query.title = this.title;
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

prototype._viewOperationMenu = function(info) {
    var query = {};
    var controller;

    query.serverList = info;
    query.isAggregatedDevice = this._isAggregatedDevice;
    controller = new AggregationOperationMenuDialogController(query);
    controller.addEventListener(UPDATE, this._updateList, this);
    controller.start();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._clickRefresh = function() {
    this._updateList();
};

prototype._clickSelect = function() {
    this._view.switchSelect();
};

prototype._clickOperate = function(e) {
    var info = [];
    var infoLen;

    for (var key in e.args) {
        info.push(e.args[key]);
    }
    infoLen = info.length;

    if (infoLen === 0) {
        this._errorDialog(_('vdms_aggregation_error_not_selected_server'));
        return;
    }

    this._viewOperationMenu(info);
};

prototype._updateList = function() {
    this._view.cleanList();
    this._fetchList();
};

}());
