/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule compression-setting-dialog-controller
 */

(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var ConpressionSettingDialogView = dixim.ctt.ConpressionSettingDialogView;
var ContentsTransferApiClient = dixim.ctt.api.ContentsTransferApiClient;
var ConfirmationDialogController = dixim.ctt.ad.ConfirmationDialogController;
var _ = dixim.ctt.ResourceBundle.get;

var CompressionSettingDialogController;
var prototype;

/**
 * @class CompressionSettingDialogController
 * @constructor
 * @param {Object} configs
 */
CompressionSettingDialogController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(CompressionSettingDialogController, EventTarget);
dixim.ctt.CompressionSettingDialogController = CompressionSettingDialogController;
prototype = CompressionSettingDialogController.prototype;

/**
 * Triggered when the deletion has been done.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {Object} event.args.deleted true if the deletion is completed, otherwise false.
 */
var CLOSE = 'close';

/**
 * Triggered when the setting has been done.
 *
 * @event delete
 * @param {Event} event
 * @param {Object} event.args
 */
var SETTING = 'setting';

/**
 * Triggered when the cancel has been done.
 *
 * @event cancel
 * @param {Event} event
 * @param {Object} event.args
 */
var CANCEL = 'cancel';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._view = new ConpressionSettingDialogView(configs);
  this._session = null;
  this._model = new ContentsTransferApiClient();
  this._finished = configs.finish || function() {return;};
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener(SETTING, this._didClickSetting, this);
  v.addEventListener(CANCEL, this._didClickCancel, this);

  v.show();
};

prototype._didClickSetting = function(e) {
  var data = e.args;
  var cdc;
  var query = {};
  var model = this._model;

  this._didFinish();

  if (typeof data.availability !== 'undefined') {
    this._model.updateAvailabilityCompression({availability: data.availability});
  }
  if (typeof data.availability !== 'undefined' && typeof data.preset_id === 'undefined') {
    this._finished();
  }
  if (typeof data.preset_id !== 'undefined') {
    query = {
      title: _('ctt_compression_setting_confirmation_title'),
      description: _('ctt_compression_setting_confirmation_description'),
      isDelete: false
    };

    query.processing = function() {
      model.updatePreset({id: data.preset_id});
      this.finish();
    };

    query.finish = this._finished;
    cdc = new ConfirmationDialogController(query);
    cdc.start();
  }
};

prototype._didClickCancel = function() {
  this._didFinish();
};

prototype._didFinish = function() {
  this._view.destroy();
  this.dispatchEvent(new Event(CLOSE));
};

/**
 * @method finish
 */
prototype.finish = function() {
  this._didFinish();
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

}());
