/**
 * @module ctt
 * @submodule parental-lockcontroller
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var ParentalLockView = dixim.ctt.ParentalLockView;
var ContentsTransferApiClient = dixim.ctt.api.ContentsTransferApiClient;

var ParentalLockController;
var prototype;

/**
 * @class ParentalLockController
 * @constructor
 * @param {Object} configs
 * @param {ContentsTransferApiClient} [configs.model]
 */
ParentalLockController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(ParentalLockController, EventTarget);
dixim.ctt.ParentalLockController = ParentalLockController;
prototype = ParentalLockController.prototype;

/**
 * Triggered when the dialog has been closed.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {String} event.args.pin valid PIN if the PIN matching was successfully completed, null otherwise.
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItem
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._model = configs.model || new ContentsTransferApiClient();
  this._view = new ParentalLockView();
  this._session = null;
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;
  var m = this._model;

  v.addEventListener('unlock', this._didClickUnlock, this);
  v.addEventListener('cancel', this._didClickCancel, this);

  m.addEventListener('matchPinCode', this._didMatchPinCode, this);
  m.addEventListener('matchPinCodeError', this._didFailMatchPinCode, this);

  v.show();
};

prototype._isValidPin = function(pin) {
  if (!!!pin) return false;
  if (/[^0-9]/.test(pin)) return false;
  if (pin.length !== 4) return false;
  return true;
};

prototype._didClickUnlock = function(e) {
  var pin = e.args.pin;

  if (!!this._session) return;

  if (!this._isValidPin(pin)) {
    this._view.showError();
    return;
  }
  this._view.showActivityIndicator();
  this._session = this._model.matchPinCode({code: pin});
};

prototype._didMatchPinCode = function(e) {
  this._view.destroy();
  this.dispatchEvent(new Event(CLOSE, {pin: e.args.pin}));
  this._session = null;
};

prototype._didFailMatchPinCode = function(e) {
  this._view.hideActivityIndicator();
  this._view.showError();
  this._session = null;
};

prototype._didClickCancel = function() {
  // TODO:
  if (!!this._session) return;
  this._view.destroy();
  this.dispatchEvent(new Event(CLOSE, {pin: null}));
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

}());
