/**
 * @module ctt
 * @submodule transfer-status-listing-controller
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var TransferStatusListingView = dixim.ctt.TransferStatusListingView;

var TransferStatusListingController;
var prototype;

/**
 * @class TransferStatusListingController
 * @constructor
 * @param {Object} configs
 */
TransferStatusListingController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(TransferStatusListingController, EventTarget);
dixim.ctt.TransferStatusListingController = TransferStatusListingController;
prototype = TransferStatusListingController.prototype;

/**
 * Triggered when the status dialog has been closed.
 * 
 * @event close
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {String|jQuery} configs.containerNode
 */
prototype._initialize = function(configs) {
  this._containerNode = configs.containerNode;
  this._view = new TransferStatusListingView({containerNode: this._containerNode});
};

/**
 * @method start
 */
prototype.start = function() {
  this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._view.hide();
  
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

/**
 * @method updateStatus
 * @param {Object[]} records
 */
prototype.updateStatus = function(records) {
  this._view.updateRecords(records);
};

prototype.clearRecord = function() {
  this._view.removeAllRows();
};

}());
