/**
 * @module ctt
 * @submodule schedule-entry-deletion-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var WizardPageView = dixim.ctt.WizardPageView;
var TickerView = dixim.ctt.TickerView;
var Template = dixim.ctt.util.Template;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ScheduleEntryDeletionWizardPageView;
var prototype;
var superConstructor;

/**
 * @class ScheduleEntryDeletionWizardPageView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
ScheduleEntryDeletionWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(ScheduleEntryDeletionWizardPageView, WizardPageView);
dixim.ctt.ScheduleEntryDeletionWizardPageView = ScheduleEntryDeletionWizardPageView;
prototype = ScheduleEntryDeletionWizardPageView.prototype;
superConstructor = ScheduleEntryDeletionWizardPageView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-schedule-entry-deletion-wizard-page-view-wrapper" />';

var TEMPLATE_BODY_CONTENT = ['<div class="ctt-schedule-entry-deletion-wizard-page-view">',
                               '<div class="ctt-schedule-entry-deletion-wizard-page-view-message-wrapper">',
                                 '<div class="ctt-schedule-entry-deletion-wizard-page-view-description">${description}</div>',
                                 '<div class="ctt-schedule-entry-deletion-wizard-page-view-error"></div>',
                               '</div>',
                               '<div class="ctt-schedule-entry-deletion-wizard-page-view-entry-list"></div>',
                             '</div>'].join('');

var TEMPLATE_LOADING = Template.LOADING_OVERLAY;

/**
 * Triggered when the cancel button was clicked.
 *
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * Triggered when the delete button was clicked.
 *
 * @event delete
 */
var DELETE = 'delete';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var bodyContent;

  configs  = configs || {};

  buttons = [
    {
      'text': _('ctt_dialog_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    },
    {
      'text': _('ctt_transfer_schedule_view_button_label_delete'),
      click: $.proxy(this._didClickDelete, this),
      'class': 'ctt-schedule-entry-deletion-wizard-page-view-button-delete'
    }
  ];

  bodyContent = TEMPLATE_BODY_CONTENT.
                replace('${description}', _('ctt_schedule_entry_deletion_wizard_page_view_description'));

  configs.title = _('ctt_schedule_entry_deletion_wizard_page_view_title');
  configs.contentBox = configs.contentBox || TEMPLATE_CONTENT_BOX;
  configs.bodyContent = configs.bodyContent || bodyContent;
  configs.buttons = buttons;

  this._loading = null;
  this._ticker = null;
  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didRenderDialog = function(e) {
  var ticker;

  ticker = new TickerView({
    containerNode: $('.ctt-schedule-entry-deletion-wizard-page-view-error', this._view),
    type: 'error'
  });
  ticker.addEventListener('hide', this._didChangeTickerVisibility, this);
  ticker.addEventListener('show', this._didChangeTickerVisibility, this);
  this._ticker = ticker;

  this._loading = $(TEMPLATE_LOADING);
  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didChangeTickerVisibility = function() {
  this._adjustListHeight();
};

prototype._didOpenDialog = function() {
  this._adjustListHeight();
  superConstructor.prototype._didOpenDialog.apply(this, arguments);
};

prototype._adjustListHeight = function() {
  var v = this._view;
  var list;
  var desc;

  list = $('.ctt-schedule-entry-deletion-wizard-page-view-entry-list', v);
  desc = $('.ctt-schedule-entry-deletion-wizard-page-view-message-wrapper', v);
  list.height(Math.floor(v.height() - desc.outerHeight(true)));
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._cancelDialog();
};

prototype._didClickCancel = function(e) {
  this._cancelDialog();
};

prototype._cancelDialog = function() {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickDelete = function(e) {
  this.dispatchEvent(new Event(DELETE));
};

prototype.getBodyContent = function() {
  return $('.ctt-schedule-entry-deletion-wizard-page-view-entry-list',
           this._view);
};

/**
 * @method showError
 * @param {String} error
 */
prototype.showError = function(error) {
  this._showError(error);
};

prototype._showError = function(error) {
  this._ticker.setText(error);
  this._ticker.show();
};

prototype.showActivityIndicator = function() {
  var p = this._view;

  this._loading.width(p.innerWidth()).
                height(p.innerHeight()).
                appendTo(this._view);

  this.disableButtons();
  this.hideCloseButton();
  this._ticker.hide(false);
};

prototype.hideActivityIndicator = function() {
  this._loading.detach();
  this.enableButtons();
  this.showCloseButton();
};

}());