/**
 * @module ctt
 * @submodule transaction-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var WizardPageView = dixim.ctt.WizardPageView;
var TickerView = dixim.ctt.TickerView;
var Template = dixim.ctt.util.Template;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var TransactionWizardPageView;
var prototype;
var superConstructor;

/**
 * @class TransactionWizardPageView
 * @extends WizardPageView
 * @constructor
 * @param {Object} configs
 */
TransactionWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(TransactionWizardPageView, WizardPageView);
dixim.ctt.TransactionWizardPageView = TransactionWizardPageView;
prototype = TransactionWizardPageView.prototype;
superConstructor = TransactionWizardPageView.superConstructor;

var TEMPLATE = ['<div class="ctt-transaction-wizard-page-view">',
                  '<div class="ctt-transaction-wizard-page-view-description"></div>',
                  '<div class="ctt-transaction-wizard-page-view-error"></div>',
                '</div>'].join('');

var TEMPLATE_LOADING = Template.LOADING_ICON_SMALL;

/**
 * Triggered when the view has been rendered.
 * 
 * @event render
 */
var RENDER = 'render';

/**
 * @event retry
 */
var RETRY = 'retry';

/**
 * @event back
 */
var BACK = 'back';

/**
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * @event close
 */
var CLOSE = 'close';

var BUTTONS_ERROR = [];
var BUTTONS_COMPLETE = [];

var _initializeErrorButtons = function() {
  BUTTONS_ERROR = [
    {
      text: _('ctt_transfer_wizard_button_label_retry'),
      click: $.proxy(this._didClickRetry, this)
    },
    {
      text: _('ctt_transfer_wizard_button_label_back'),
      click: $.proxy(this._didClickBack, this)
    },
    {
      text: _('ctt_transfer_wizard_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];
};

var _initializeCompleteButtons = function() {
  BUTTONS_COMPLETE = [
    {
      text: _('ctt_transfer_wizard_button_label_close'),
      click: $.proxy(this._didClickClose, this)
    }
  ];
};


/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var cfg;
  var body;

  body = TEMPLATE;
  cfg = {
    title: _('ctt_transfer_wizard_title'),
    bodyContent: body
  };

  cfg = dixim.extend(cfg, configs);
  superConstructor.prototype._initialize.call(this, cfg);

  this._containerNode = null;
  this._descriptionNode = null;
  this._ticker = null;
  this._loading = null;

  _initializeErrorButtons.call(this);
  _initializeCompleteButtons.call(this);
};

prototype._didRenderDialog = function(e) {
  var v = this._view;

  this._loading = $(TEMPLATE_LOADING);
  this._containerNode = v.parent();
  this._descriptionNode = $('.ctt-transaction-wizard-page-view-description', v);
  this._ticker = new TickerView({
    containerNode: $('.ctt-transaction-wizard-page-view-error', v),
    type: 'error'
  });
  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype.showActivityIndicator = function() {
  this._showActivityIndicator(_('ctt_transaction_wizard_page_view_description_work_in_progress'));
};

prototype.showWolTransactionActivityIndicator = function() {
  this._showActivityIndicator(_('ctt_transaction_wizard_page_view_description_wol_work_in_progress'));
};

prototype.showScheduledTransactionActivityIndicator = function() {
  this._showActivityIndicator(_('ctt_transaction_wizard_page_view_description_scheduling_work_in_progress'));
};

prototype._showActivityIndicator = function(text) {
  this._ticker.hide(false);
  this._descriptionNode.text(text);
  this._descriptionNode.prepend(this._loading);
  this.disableButtons();
  this.hideCloseButton();
};

prototype.hideActivityIndicator = function() {
  this._loading.detach();
  this.enableButtons();
  this.showCloseButton();
};

prototype._getErrorText = function(errorCode) {
  var error;

  if (errorCode >= 470 && errorCode <= 478) {
    error = _(['ctt_transaction_wizard_page_view_error_', errorCode].join(''));
  } else {
    error = _('ctt_transaction_wizard_page_view_error', errorCode);
  }

  return error;
};

prototype.showReservationError = function(errorCode) {
  this._showError([
    _('ctt_transaction_wizard_page_view_description_reservation_error'),
    this._getErrorText(errorCode)
  ].join(''));
};

prototype.showWolError = function(errorCode) {
  this._showError([
    _('ctt_transaction_wizard_page_view_description_wol_error'),
    this._getErrorText(errorCode)
  ].join(''));
};

prototype.showError = function(errorCode) {
  this._showError([
    _('ctt_transaction_wizard_page_view_description_wol_error'),
    this._getErrorText(errorCode)
  ].join(''));
};

prototype._showError = function(error) {
  this._ticker.setText(error);
  this._ticker.show();
  this.setButtons(BUTTONS_ERROR);
};

prototype.showReservationComplete = function() {
  this._descriptionNode.text(_('ctt_transaction_wizard_page_view_reservation_complete'));
  this.setButtons(BUTTONS_COMPLETE);
};

prototype._didClickRetry = function(e) {
  this.dispatchEvent(new Event(RETRY));
};

prototype._didClickBack = function(e) {
  this.dispatchEvent(new Event(BACK));
};

prototype._didClickCancel = function(e) {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickClose = function(e) {
  this.dispatchEvent(new Event(CLOSE));
};

}());
