/**
 * @module ctt
 * @submodule parental-lock-view
 */
(function() {
var Event = dixim.event.Event;
var ModalDialogView = dixim.ctt.ModalDialogView;
var Template = dixim.ctt.util.Template;
var TickerView = dixim.ctt.TickerView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ParentalLockView;
var prototype;
var superConstructor;

/**
 * @class ParentalLockView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
ParentalLockView = function(configs) {
  ModalDialogView.call(this, configs);
};
dixim.inherit(ParentalLockView, ModalDialogView);
dixim.ctt.ParentalLockView = ParentalLockView;
prototype = ParentalLockView.prototype;
superConstructor = ParentalLockView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-parental-lock-view-wrapper" />';

var TEMPLATE_BODY_CONTENT = ['<div class="ctt-parental-lock-view">',
                               '<div class="ctt-parental-lock-view-description">${desc}</div>',
                               '<div class="ctt-parental-lock-view-error"></div>',
                               '<div class="ctt-parental-lock-view-form-wrapper">',
                                 '<form class="ctt-parental-lock-view-form"><table>',
                                   '<tr class="ctt-parental-lock-view-form-row ctt-parental-lock-view-form-pin-row">',
                                     '<td>${pin}</td>',
                                     '<td class="ctt-parental-lock-view-form-row-value"><input type="password" length="4" name="pin" /></td></tr>',
                                 '</table></form>',
                               '</div>',
                             '</div>'].join('');

var TEMPLATE_LOADING = Template.LOADING_ICON_SMALL;

/**
 * Triggered when the cancel button was clicked.
 *
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * Triggered when the unlock button was clicked.
 *
 * @event unlock
 * @param {Event} event
 * @param {Object} event.args
 * @param {String} event.args.pin
 */
var UNLOCK = 'unlock';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var bodyContent;

  configs  = configs || {};

  buttons = [
    {
      'text': _('ctt_parental_lock_view_button_label_unlock'),
      click: $.proxy(this._didClickUnlock, this)
    },
    {
      'text': _('ctt_dialog_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  bodyContent = TEMPLATE_BODY_CONTENT.
                replace('${desc}', _('ctt_parental_lock_view_description')).
                replace('${pin}', _('ctt_parental_lock_view_form_row_label_pin'));

  configs.title = _('ctt_parental_lock_view_title');
  configs.contentBox = configs.contentBox || TEMPLATE_CONTENT_BOX;
  configs.bodyContent = configs.bodyContent || bodyContent;
  configs.buttons = buttons;
  configs.width = 480;
  configs.height = 'auto';
  configs.maxHeight = 340;

  this._descriptionNode = null;
  this._ticker = null;
  this._formNode = null;

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didRenderDialog = function(e) {
  var v = this._view;
  var f;

  this._loading = $(TEMPLATE_LOADING);
  this._descriptionNode = $('.ctt-parental-lock-view-description', v);
  this._ticker = new TickerView({
    containerNode: $('.ctt-parental-lock-view-error', v),
    type: 'error'
  });
  f = $('form.ctt-parental-lock-view-form', v);

  f.bind('submit', $.proxy(this._didSubmitPin, this));
  this._formNode = f;

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._didCancel();
};

prototype._didClickCancel = function(e) {
  this._didCancel();
};

prototype._didCancel = function() {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickUnlock = function(e) {
  this._didInvokeUnlock();
};

prototype._didSubmitPin = function(e) {
  e.preventDefault();
  this._didInvokeUnlock();
};

prototype._didInvokeUnlock = function() {
  this.dispatchEvent(new Event(UNLOCK, {pin: this._getPin()}));
};

/**
 * @method showError
 */
prototype.showError = function() {
  this._showError();
};

prototype._showError = function() {
  this._ticker.setText(_('ctt_parental_lock_view_error_invalid_pin'));
  this._ticker.show();
};

prototype.getPin = function() {
  return this._getPin();
};

prototype._getPin = function() {
  return $('input[name="pin"]', this._formNode).val();
};

prototype.showActivityIndicator = function() {
  var buttonSet;

  buttonSet = $('.ui-dialog-buttonset', this._view.parent());
  $(buttonSet).append(this._loading);

  this._ticker.hide(false);
  $('input', this._formNode).attr('disabled', true);
  this.disableButtons();
  this.hideCloseButton();
};

prototype.hideActivityIndicator = function() {
  this._loading.detach();
  $('input', this._formNode).attr('disabled', false);
  this.enableButtons();
  this.showCloseButton();
};

}());