/**
 * @module dixim
 * @submodule common 
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule top-menu-controller
 */

(function() {
var TopMenuController;
var prototype;
var superConstructor;
var TopMenuView = dixim.common.TopMenuView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var Svg = dixim.common.Svg;
var HomeMenuController = dixim.common.HomeMenuController;
var UiFunctionManager = dixim.ctt.util.UiFunctionManager;
var $ = dixim.ctt.jQuery;

/**
 * @class TopMenuController
 * @constructor
 * @param {Object} configs
 */
TopMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(TopMenuController, EventTarget);
dixim.common.TopMenuController = TopMenuController;
prototype = TopMenuController.prototype;
superConstructor = TopMenuController.superConstructor;

var MENU_SKIP = 'menuSkip';
var CONTENTS = 'contents';
var DOWNLOAD = 'download';
var SERVER = 'server';
var EONKYO = 'eonkyo';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._view = new TopMenuView(configs);
    this._view.addEventListener(MENU_SKIP, this._clickMenuSkip, this);
    this._view.addEventListener(CONTENTS, this._clickMenuContents, this);
    this._view.addEventListener(SERVER, this._clickMenuServer, this);
    this._view.addEventListener(EONKYO, this._clickMenuEonkyo, this);
};

/**
 * @method start
 */
prototype.start = function() {
    var dataList = [];
    var dataListLen;
    var olDataList = [];
    var olDataListLen;

    if (UiFunctionManager.isImplement('server')) {
        olDataList.push({svg: Svg.get('SETTING_SERVER'), name: _('common_top_setting_server'), event_param: SERVER});
    }
    if (UiFunctionManager.isImplement('contents')) {
        dataList.push({svg: Svg.get('CONTENTS'), name: _('common_top_contents'), event_param: CONTENTS});
    }
    if (UiFunctionManager.isImplement('eonkyo')) {
        olDataList.push({svg: Svg.get('SETTING_EONKYO'), name: _('common_top_setting_eonkyo'), event_param: EONKYO});
    }

    this._view.show();

    dataListLen = dataList.length;
    olDataListLen = olDataList.length;
    if (olDataListLen !== 0) {
        dataList.push({svg: Svg.get('SETTING'), name: _('common_top_setting'), trigger_name: 'trigger3'});
        dataListLen = dataList.length;
    }

    for (var i = 0; i < dataListLen; i += 1) {
        this._view.addMainButton(dataList[i]);
    }

    for (var i = 0; i < olDataListLen; i += 1) {
        this._view.addOverlayButton(olDataList[i]);
    }

    this._view.setEffect();

    $(window).resize(dixim.proxy(function() {
        var timer = false;

        if (timer !== false) {
            clearTimeout(timer);
        }
        timer = setTimeout(dixim.proxy(function() {
            this._view.setEffect();
        }, this), 500);
    }, this));
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._homeMenu = function() {
    var controller = new HomeMenuController();

    controller.start();

    return controller;
};

prototype._contentsView = function() {
    var controller;
    var query = {};

    query.parentContext = this._homeMenu();
    controller = new dixim.contents.ContentsMenuController(query);
    controller.start();
};

prototype._serverView = function() {
    var controller;
    var query = {};

    query.parentContext = this._homeMenu();
    controller = new dixim.server.ServerMenuController(query);
    controller.start();
};

prototype._downloadView = function() {
    var controller;
    var query = {};

    query.parentContext = this._downloadMenuView();
    controller = new dixim.download.DownloadController(query);
    controller.start();
};

prototype._downloadMenuView = function() {
    var controller;
    var query = {};

    query.parentContext = this._homeMenu();
    controller = new dixim.download.DownloadMenuController(query);
    controller.start();
    return controller;
};

prototype._eonkyoView = function() {
    var controller;
    var query = {};

    query.parentContext = this._downloadMenuView();
    controller = new dixim.download.EonkyoMenuController(query);
    controller.start();
};

prototype._clickMenuSkip = function() {
    this._view.hide();
    this._homeMenu();
};

prototype._clickMenuContents = function() {
    this._view.hide();
    this._contentsView();
};

prototype._clickMenuServer = function() {
    this._view.hide();
    this._serverView();
};

prototype._clickMenuEonkyo = function() {
    this._view.hide();
    this._eonkyoView();
};

}());
