/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule rename-dialog-view
 */
(function() {
var RenameDialogView;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var TickerView = dixim.ctt.TickerView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var UiUtils = dixim.common.UiUtils;

/**
 * @class RenameDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
RenameDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(RenameDialogView, ModalDialogView);
dixim.contents.RenameDialogView = RenameDialogView;
prototype = RenameDialogView.prototype;
superConstructor = RenameDialogView.superConstructor;

var CANCEL = 'cancel';
var RENAME = 'rename';

var TEMPLATE_CONTENT_BOX = '<div class="ctt-renaming-view-wrapper" />';

var TEMPLATE_BODY_CONTENT = [
    '<div id="ctt-renaming-description" class="ctt-renaming-view-description dlg_main_msg">', '${desc}',
    '<div class="ctt-renaming-view-ticker-wrapper"></div>',
    '</div>',
    '<div class="ctt-renaming-view">',
    '<div class="ctt-renaming-view-form-wrapper">',
    '<form class="ctt-renaming-view-form dl_tbl">',
    '<dl id="ctt-renaming-old-name">',
    '<dt class="ctt-renaming-view-form-row">', '${old_name}', '</dt>',
    '<dd class="ctt-renaming-view-form-row-value"></dd>',
    '</dl>',
    '<dl id="ctt-renaming-new-name" class="none_border_bottom">',
    '<dt class="ctt-renaming-view-form-row">', '${new_name}', '</dt>',
    '<dd class="ctt-renaming-view-form-row-value">', '<input type="hidden" id="hidden_field" />', '<input type="text" id="rename_field" name="newName" maxlength="255" />', '</dd>',
    '</dl>',
    '</form>',
    '</div>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    var buttons;
    var bodyContent;

    configs  = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'rename-dialog'].join('');

    buttons = [
        {
            text: _('dialog_cancel'),
            click: dixim.proxy(this.clickCancel, this)
        },
        {
            text: _('dialog_edit'),
            class: 'ctt-renaming-view-button-rename',
            click: dixim.proxy(this._clickRename, this)
        },
    ];

    bodyContent = TEMPLATE_BODY_CONTENT.
        replace('${desc}', _('contents_rename_dialog_description')).
        replace('${old_name}', _('contents_rename_dialog_row_label_old')).
        replace('${new_name}', _('contents_rename_dialog_row_label_new'));

    configs.title = _('contents_operation_menu_rename');
    configs.contentBox = configs.contentBox || TEMPLATE_CONTENT_BOX;
    configs.bodyContent = configs.bodyContent || bodyContent;
    configs.buttons = buttons;
    configs.height = 'auto';

    this._uiUtils = UiUtils;
    this._descriptionNode = null;
    this._ticker = null;
    this._formNode = null;
    this._targetItem = null;
    this._cpRename = null;

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function(e) {
    var f;
    var tfeRename;

    this._descriptionNode = $('.ctt-renaming-view-description', this._view);
    this._ticker = new TickerView({
        containerNode: $('.ctt-renaming-view-ticker-wrapper', this._view),
        type: 'error'
    });
    f = $('form.ctt-renaming-view-form', this._view);

    f.bind('submit', dixim.proxy(this._submitNewName, this));
    this._formNode = f;

    $('#ctt-renaming-new-name input').on('blur', function() {
        setTimeout(function() {
            $('body').scrollTop($('body').scrollTop() + 1);
            $('body').scrollTop($('body').scrollTop() + 1);
        }, 100);
    });

    tfeRename = new this._uiUtils.textFocusEvent();
    tfeRename.set('#rename_field', '#hidden_field');

    this._cpRename = new this._uiUtils.clearPanelOnTextField('#rename_field');
    this._cpRename.set();

    superConstructor.prototype._render.call(this, e);
};

prototype.clickCancel = function(e) {
    this._cancel();
};

prototype._cancel = function() {
    $('body').animate({scrollTop: 0}, 'fast');
    this.dispatchEvent(new Event(CANCEL));
};

prototype._clickRename = function(e) {
    this.invokeRename();
};

prototype._submitNewName = function(e) {
    e.preventDefault();
    this.invokeRename();
};

prototype.invokeRename = function() {
    $('body').animate({scrollTop: 0}, 'fast');
    this.dispatchEvent(new Event(RENAME, {newName: this._getNewName(), targetItem: this._targetItem}));
};

prototype.showError = function(text) {
    this._showError(text);
};

prototype._showError = function(text) {
    text = text || '';

    this._ticker.setText(text);
    this._ticker.show();
};

prototype._getNewName = function() {
    return $('input[type="text"][name="newName"]', this._formNode).val();
};

prototype.updateTargetItem = function(item) {
    this._updateTargetItem(item);
};

prototype._updateTargetItem = function(item) {
    this._targetItem = item;
    $('#ctt-renaming-old-name dd').text(item.title || '');
    $('#ctt-renaming-old-name input[type="text"]').val('');
    $('#ctt-renaming-new-name input[name="newName"]').val(item.title || '');
    this._cpRename.reposition();
};

prototype.showActivityIndicator = function() {
    this._ticker.hide(false);
    this.startIndicator();
};

prototype.hideActivityIndicator = function() {
    this.stopIndicator();
};

}());
